==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-he-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hebrew (http://www.transifex.com/tine20/tine20/language/he/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: he\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: ""

, "Hostname"
: ""

, "Username"
: ""

, "Password"
: ""

, "Port"
: ""

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: ""

, "SSL"
: ""

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: ""

, "Yes"
: ""

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: ""

, "MySql Database"
: ""

, "MySql User"
: ""

, "MySql Password"
: ""

, "MySql Port"
: ""

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: ""

, "Error"
: ""

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Install application"
: ""

, "File"
: ""

, "Setup Authentication"
: ""

, "Database"
: ""

, "User"
: ""

, "Prefix"
: ""

, "Logging"
: ""

, "Filename"
: ""

, "Priority"
: ""

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: ""

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Save config"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: ""

, "Application Manager"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: ""

, "Login name"
: ""

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "Setup"
: ""

, "Application, Applications"
: [
  ""
 ,""
 ,""
 ,""

]
, "Name"
: ""

, "Enabled"
: ""

, "Order"
: ""

, "Installed Version"
: ""

, "Available Version"
: ""

, "Status"
: ""

, "Depends on"
: ""

, "Uninstall application"
: ""

, "Update application"
: ""

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: ""

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Application"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-he-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hebrew (http://www.transifex.com/tine20/tine20/language/he/)\nLanguage: he\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""

, "Backend"
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: ""

, "Hostname"
: ""

, "Username"
: ""

, "Password"
: ""

, "Port"
: ""

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: ""

, "SSL"
: ""

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: ""

, "Yes"
: ""

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: ""

, "MySql Database"
: ""

, "MySql User"
: ""

, "MySql Password"
: ""

, "MySql Port"
: ""

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: ""

, "Application Manager"
: ""

, "Setup"
: ""

, "Name"
: ""

, "Enabled"
: ""

, "Order"
: ""

, "Installed Version"
: ""

, "Available Version"
: ""

, "Status"
: ""

, "Depends on"
: ""

, "Install application"
: ""

, "Uninstall application"
: ""

, "Update application"
: ""

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: ""

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: ""

, "Login name"
: ""

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Save config"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: ""

, "Error"
: ""

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Application, Applications"
: [
  ""
 ,""
 ,""
 ,""

]
, "File"
: ""

, "Setup Authentication"
: ""

, "Database"
: ""

, "User"
: ""

, "Prefix"
: ""

, "Logging"
: ""

, "Filename"
: ""

, "Priority"
: ""

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: ""

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
